Hallo Kollege,

#if $instance.state.name == 'invited' ich lade dich zu folgendem Termin ein: #end if #if $instance.state.name == 'accepted' du hast zu folgendem Termin zugesagt: #end if

- am $dtosl($instance.event.start_date) um $dtosl($instance.event.start_time) Uhr
- $instance.event.calendar

Bitte bestätige, indem du du in Lino unter Meine offenen erhaltenen Einladungen auf [Zusagen] klickst!

Mit freundlichen Grüßen
$instance.event.user